==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/sector/bg/_0204/OBWAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * Overig bouwwerk binnen antwoordbericht
 * 
 * <p>Java class for OBW-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OBW-antwoord">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}OBW-fund">
 *       &lt;sequence>
 *         &lt;element name="OBW" type="{http://www.egem.nl/StUF/sector/bg/0204}OBW-fund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="OBWADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="OBWKDO" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="OBWBSG" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OBW-antwoord", propOrder = {
    "obw",
    "obwadr",
    "obwkdo",
    "obwbsg"
})
public class OBWAntwoord
    extends OBWFund
{

    @XmlElement(name = "OBW")
    protected List<OBWFund> obw;
    @XmlElement(name = "OBWADR", nillable = true)
    protected List<ADRRelFund> obwadr;
    @XmlElement(name = "OBWKDO", nillable = true)
    protected List<OBWAntwoord.OBWKDO> obwkdo;
    @XmlElement(name = "OBWBSG", nillable = true)
    protected List<OBWAntwoord.OBWBSG> obwbsg;

    /**
     * Gets the value of the obw property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obw property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBW().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link OBWFund }
     * 
     * 
     */
    public List<OBWFund> getOBW() {
        if (obw == null) {
            obw = new ArrayList<OBWFund>();
        }
        return this.obw;
    }

    /**
     * Gets the value of the obwadr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obwadr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBWADR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getOBWADR() {
        if (obwadr == null) {
            obwadr = new ArrayList<ADRRelFund>();
        }
        return this.obwadr;
    }

    /**
     * Gets the value of the obwkdo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obwkdo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBWKDO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link OBWAntwoord.OBWKDO }
     * 
     * 
     */
    public List<OBWAntwoord.OBWKDO> getOBWKDO() {
        if (obwkdo == null) {
            obwkdo = new ArrayList<OBWAntwoord.OBWKDO>();
        }
        return this.obwkdo;
    }

    /**
     * Gets the value of the obwbsg property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obwbsg property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBWBSG().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link OBWAntwoord.OBWBSG }
     * 
     * 
     */
    public List<OBWAntwoord.OBWBSG> getOBWBSG() {
        if (obwbsg == null) {
            obwbsg = new ArrayList<OBWAntwoord.OBWBSG>();
        }
        return this.obwbsg;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class OBWBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGFund bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGFund }
         *     
         */
        public BSGFund getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGFund }
         *     
         */
        public void setBSG(BSGFund value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class OBWKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKennisgeving kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKennisgeving }
         *     
         */
        public KDOKennisgeving getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKennisgeving }
         *     
         */
        public void setKDO(KDOKennisgeving value) {
            this.kdo = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/OBWAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * Overig bouwwerk binnen antwoordbericht
 * 
 * <p>Java class for OBW-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OBW-antwoord"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}OBW-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="OBW" type="{http://www.egem.nl/StUF/sector/bg/0204}OBW-fund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="OBWADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="OBWKDO" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="OBWBSG" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OBW-antwoord", propOrder = {
    "obw",
    "obwadr",
    "obwkdo",
    "obwbsg"
})
public class OBWAntwoord
    extends OBWFund
{

    @XmlElement(name = "OBW")
    protected List<OBWFund> obw;
    @XmlElement(name = "OBWADR", nillable = true)
    protected List<ADRRelFund> obwadr;
    @XmlElement(name = "OBWKDO", nillable = true)
    protected List<OBWAntwoord.OBWKDO> obwkdo;
    @XmlElement(name = "OBWBSG", nillable = true)
    protected List<OBWAntwoord.OBWBSG> obwbsg;

    /**
     * Gets the value of the obw property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obw property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBW().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link OBWFund }
     * 
     * 
     */
    public List<OBWFund> getOBW() {
        if (obw == null) {
            obw = new ArrayList<OBWFund>();
        }
        return this.obw;
    }

    /**
     * Gets the value of the obwadr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obwadr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBWADR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getOBWADR() {
        if (obwadr == null) {
            obwadr = new ArrayList<ADRRelFund>();
        }
        return this.obwadr;
    }

    /**
     * Gets the value of the obwkdo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obwkdo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBWKDO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link OBWAntwoord.OBWKDO }
     * 
     * 
     */
    public List<OBWAntwoord.OBWKDO> getOBWKDO() {
        if (obwkdo == null) {
            obwkdo = new ArrayList<OBWAntwoord.OBWKDO>();
        }
        return this.obwkdo;
    }

    /**
     * Gets the value of the obwbsg property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the obwbsg property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getOBWBSG().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link OBWAntwoord.OBWBSG }
     * 
     * 
     */
    public List<OBWAntwoord.OBWBSG> getOBWBSG() {
        if (obwbsg == null) {
            obwbsg = new ArrayList<OBWAntwoord.OBWBSG>();
        }
        return this.obwbsg;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class OBWBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGFund bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGFund }
         *     
         */
        public BSGFund getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGFund }
         *     
         */
        public void setBSG(BSGFund value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class OBWKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKennisgeving kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKennisgeving }
         *     
         */
        public KDOKennisgeving getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKennisgeving }
         *     
         */
        public void setKDO(KDOKennisgeving value) {
            this.kdo = value;
        }

    }

}
